import { GetServerUrl } from './config.js';


document.addEventListener('DOMContentLoaded', () => {
    const modal = document.getElementById('table-modal');
    const showTableBtn = document.getElementById('show-table-btn');
    const closeBtn = document.getElementById('close-btn');
    const downloadBtn = document.getElementById('download-btn');
    const tableContainer = document.getElementById('table-container');

    function getTime(){
        const queryYear = document.querySelector('.queryYear')
        const queryMonth = document.querySelector('.queryMonth')
        let year = queryYear.value
        let month = queryMonth.value
        const date = new Date(year, month, 1)
        return Math.floor(date.getTime() / 1000) -1
    }

    // Sample data for the table
    const data = [];

    // Function to create table
    function createTable(data) {
        const table = document.createElement('table');
        const thead = document.createElement('thead');
        const tbody = document.createElement('tbody');

        // Create table header
        const headerRow = document.createElement('tr');
        data[0].forEach(header => {
            const th = document.createElement('th');
            th.textContent = header;
            headerRow.appendChild(th);
        });
        thead.appendChild(headerRow);

        // Create table body
        for (let i = 1; i < data.length; i++) {
            const row = document.createElement('tr');
            data[i].forEach(cell => {
                const td = document.createElement('td');
                td.textContent = cell;
                row.appendChild(td);
            });
            tbody.appendChild(row);
        }

        table.appendChild(thead);
        table.appendChild(tbody);

        return table;
    }

    // Show modal and table
    showTableBtn.addEventListener('click', () => {
        let url = GetServerUrl()+'/gm_test'
        let context = {
            func : 'show_statistics',
            args : []
        }
        context.args[0] = getTime()
        axios({
            url: url,
            params: {
                context : JSON.stringify(context)
            },
        }).then(result =>{
            console.log(result.data.msg)
            const table = createTable(result.data.msg);
            tableContainer.innerHTML = '';  // Clear previous table if any
            tableContainer.appendChild(table);
            modal.style.display = 'block';
        }).catch(error =>{
            alert("查询失败")
        })
    });

    // Hide modal
    closeBtn.addEventListener('click', () => {
        modal.style.display = 'none';
    });

    window.addEventListener('click', (event) => {
        if (event.target === modal) {
            modal.style.display = 'none';
        }
    });

    // Download table as CSV
    downloadBtn.addEventListener('click', () => {
        const table = document.querySelector('#table-container table');
        if (!table) return; // Exit if no table is present

        const rows = Array.from(table.querySelectorAll('tr'));
        let csvContent = '';

        rows.forEach(row => {
            const cells = Array.from(row.querySelectorAll('td, th'));
            const rowContent = cells.map(cell => cell.textContent).join(',');
            csvContent += rowContent + '\n';
        });

        const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
        const link = document.createElement('a');
        link.href = URL.createObjectURL(blob);
        link.download = 'table-data.csv';
        link.click();
    });
});
